@@ -143,6 +143,34 @@ class KubeModel(ABC):
             pickle.dump(self.optimizer.state_dict(), f)
         print('saved state')
 
+    def _save_file_test(self):
+        """
+        Saves the optimizer state to be loaded again in
+        the following epochs
+        """
+        
+        self.logger.debug('saving file to host')
+
+        with open('/output/test.pkl', 'wb') as f:
+            self.logger.debug('saving file, epoch: {self.epoch}')
+            pickle.dump('test', f)
+            self.logger.debug('file saved')
+        print('file saved')   
+
+    def _load_file_test(self):
+        """
+        Saves the optimizer state to be loaded again in
+        the following epochs
+        """
+        
+        self.logger.debug('loading file to host')
+
+        with open('/output/test.pkl', 'wb') as f:
+            self.logger.debug('loading file, epoch: {self.epoch}')
+            state = pickle.load(f)
+            self.logger.debug('file loaded')
+            print('file loaded')    
+
     def _save_optimizer_redis(self):
         """
         Saves the optimizer to the redis
